#[non_exhaustive]pub enum Then {
Drop,
Step,
Sleep,
}Expand description
A behavior’s request for what should happen to it next.
Returned from Behavior::step(). Analogous to core::task::Poll for futures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Drop
Remove the behavior from the behavior set, and never call it again.
Step
Step again upon the next tick.
Sleep
Don’t step until the Context::waker() is invoked.