Struct all_is_cubes::behavior::BehaviorSetTransaction

source ·
pub struct BehaviorSetTransaction<H: BehaviorHost> { /* private fields */ }
A Transaction that adds or modifies Behaviors in a BehaviorSet.

Implementations

source

impl<H: BehaviorHost> BehaviorSetTransaction<H>

source

pub fn insert(attachment: H::Attachment, behavior: Arc<dyn Behavior<H>>) -> Self

Constructs a transaction that adds a behavior to the behavior set.