Struct all_is_cubes::behavior::BehaviorWaker
source · pub struct BehaviorWaker(/* private fields */);Expand description
Handle to wake up a Behavior.
We use this custom type rather than the standard Waker, which
would otherwise be suitable, because Waker is required to be Send + Sync, which is
incompatible with our no_std support.
In future versions, this may be replaced with a LocalWaker if the standard library
ever includes such a type.
This type is Send and Sync if the std feature of all-is-cubes is enabled,
and not otherwise.
Implementations
sourceimpl BehaviorWaker
impl BehaviorWaker
sourcepub fn wake(self)
pub fn wake(self)
Wake up the behavior; cause it to be invoked during the next Universe step.
This function has the same characteristics as Waker::wake() except that it
addresses a Behavior rather than a Future.
sourcepub fn wake_by_ref(&self)
pub fn wake_by_ref(&self)
Wake up the behavior; cause it to be invoked during the next Universe step.
This function has the same characteristics as Waker::wake() except that it
addresses a Behavior rather than a Future.