Context

Struct Context 

#[non_exhaustive]
pub struct Context<'ctx, 'read, H: Host> { pub tick: Tick, pub read_ticket: ReadTicket<'ctx>, pub host: &'ctx H::Read<'read>, pub attachment: &'ctx H::Attachment, /* private fields */ }
Items available to a Behavior during Behavior::step().

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tick: Tick

The time tick that is currently passing, causing this step.

read_ticket: ReadTicket<'ctx>

ReadTicket for the universe this behavior is contained in.

host: &'ctx H::Read<'read>

The current state of the behavior’s host object.

attachment: &'ctx H::Attachment

Additional data about “where” the behavior is attached to the host; what part of the host should be affected by the behavior.

Implementations

Source

impl<'a, H: Host> Context<'a, '_, H>

pub fn waker(&self) -> &'a Waker

Returns a waker that should be used to signal when the behavior’s step() should be called again, in the case where it returns Then::Sleep.

This is precisely analogous to the use of Waker with Future::poll().

pub fn bind_host(&self, transaction: H::Transaction) -> UniverseTransaction

Take a transaction applicable to the behavior’s host, and wrap it to become a UniverseTransaction for the host’s containing universe.

pub fn replace_self<B: Behavior<H> + 'static>( &self, new_behavior: B, ) -> UniverseTransaction

Returns a transaction which will replace this behavior with a new value.

This should be used whenever a behavior wishes to modify itself, to ensure that the modification only takes effect when the behavior’s other effects do.