AnimationChange

Enum AnimationChange 

#[non_exhaustive]
pub enum AnimationChange { None, ColorSameCategory, Shape, }
Component of AnimationHint, describing the type of change predicted.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

Expect no changes.



ColorSameCategory

Expect that the block’s voxels’ colors will change, while remaining within the same OpacityCategory; that is, the alpha will remain 0, remain 1, or remain neither 0 nor 1.

Suggestion to renderers: prepare to update texturing without recomputing an otherwise identical mesh.



Shape

Expect that the block’s colors and shape will change; that is, at least some voxels’ alpha will move from one OpacityCategory to another.

Suggestion to renderers: use a rendering strategy which is shape-independent, or prepare to efficiently recompute the mesh (don’t merge with neighbors).