CompositeOperator

Enum CompositeOperator 

#[non_exhaustive]
pub enum CompositeOperator { Over, In, Out, Atop, }
Compositing operators, mostly as per Porter-Duff.

The “source” block is the Composite’s stored block, and the “destination” block is the block the modifier is attached to.

TODO: Document behavior of collision and selectable properties.

Serialization stability warning

This type implements serde::Serialize and serde::Deserialize, but serialization support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes will be able to deserialize data which is serialized by this version.

Additionally, the serialization schema is designed with serde_json in mind. It is not guaranteed that using a different data format crate, which may use a different subset of the information exposed via serde::Serialize, will produce stable results.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Over

Porter-Duff “over”. If both source and destination are opaque, the source is taken; otherwise the destination is taken.



In

Porter-Duff “in”. If both source and destination are opaque, the source is taken; otherwise the result is transparent. Thus the destination acts as a mask constraining where the source is present; the source is “in” the destination. The destination’s color is not used.



Out

Porter-Duff “out”. If both source and destination are opaque, the result is transparent; otherwise the source is taken. Thus the destination acts as a mask removing portions of the source. The destination’s color is not used.



Atop

Porter-Duff “atop”. If both source and destination are opaque, the source is taken; otherwise the destination is taken. Thus the source is painted onto the destination’s substance.