#[non_exhaustive]pub enum Modifier {
Attributes(Arc<BlockAttributes>),
Tag(Be),
Quote(Quote),
Rotate(GridRotation),
Composite(Composite),
Zoom(Zoom),
Move(Move),
Inventory(Inventory),
}Expand description
Modifiers can be applied to a Block to change the result of
evaluate()ing it, and thus create variations, such as rotations
or combinations of multiple blocks.
Usage
Most modifiers have their own dedicated structs, such as Composite; these may
be converted to Modifier using their From implementations, or by constructing
the enum variant (Modifier::Composite) explicitly. Some modifiers have specific
functions for constructing their typical usages, such as Block::rotate().
Block::with_modifier() is provided to conveniently add a single modifier to a block;
Block::modifiers() and Block::modifiers_mut() provide general direct access.
Note that Block is a clone-on-write type for when modifiers are changed.
Arranging modifiers
Operations which add or remove modifiers, such as Block::rotate(),
follow some general principles and special cases:
- There should not be consecutive
Rotatemodifiers, but a single one with the combined rotation.Block::rotate()maintains this property. - It is preferable to have
Rotateappear last, since rotation and unrotation is part of player interaction, and the identity of block modifiers, not just their final result, determines whether blocks are equal for purposes of inventory management.Composite::compose_or_replace()avoids applyingCompositeafterRotate, so that rotated versions of the same combination are represented identically.
There is not yet any general “algebra” defining all cases where combinations of
modifiers should be canonicalized to other forms. Future versions of All is Cubes may
do so; that will be a breaking change (particularly since Block::modifiers_mut()
exists, so no rules are currently enforceable).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Attributes(Arc<BlockAttributes>)
Sets or overrides the attributes of the block.
Tag(Be)
Applies the given tag to this block.
Quote(Quote)
Suppresses all behaviors of the Block that might affect the space around it,
(or itself).
Rotate(GridRotation)
Rotate the block about its cube center by the given rotation.
This modifier should normally be used by means of Block::rotate().
Composite(Composite)
Combine the voxels of multiple blocks using some per-voxel rule.
Zoom(Zoom)
Zoom in on a portion of the block; become part of a multi-block structure whose parts are parts of the original block.
Move(Move)
Displace the block out of the grid, cropping it.
Inventory(Inventory)
The block has an inventory (e.g. a chest, a dropped item, a machine).
The effects this inventory has on the evaluation of this block are determined by
the InvInBlock stored in BlockAttributes::inventory.