RotationPlacementRule

Enum RotationPlacementRule 

#[non_exhaustive]
pub enum RotationPlacementRule { Never, Attach { by: Face6, }, }
Rule about how this block should be rotated, or not, when placed in a Space by some agent not otherwise specifying rotation.

TODO: We may want to replace this with a struct that also carries declared symmetries (“this is a vertical pillar so never make it upside down”) and/or prohibited rotations rather than requiring each individual rule variant to be sufficiently expressive.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Never

Never rotate the block.



Attach

Rotate the block so that the specified face meets the face it was placed against.

Fields

by: Face6

This face of the placed block will meet the face it was placed against.

If the block was somehow placed without such an adjacent block, it will not be rotated.