Atom

Struct Atom 

pub struct Atom {
    pub color: Rgba,
    pub emission: Rgb,
    pub collision: BlockCollision,
}
Data of Primitive::Atom. The definition of a single block that has uniform material properties rather than spatially varying ones; a single voxel.

All properties of an atom are intensive properties.

Fields

color: Rgba

The color exhibited by diffuse reflection from this block.

The RGB components of this color are the reflectance: the fraction of incoming light that is reflected rather than absorbed.

The alpha (α) component of this color specifies the opacity of this block, that is, the fraction of light that is reflected or absorbed rather than transmitted.

Whenever α is neither 1 nor 0 (and, trivially, in those cases too), the reflectance and opacity should be interpreted as being of a unit thickness of this material. Thus, they may be modified by the length of material through which a light ray passes, either due to viewing angle or due to using this block as a voxel in a Primitive::Recur.

This transformation is best understood in terms of transmittance T, defined as 1 − α. The transmittance of a given thickness of material, Td, is defined in terms of the transmittance of a unit thickness, T1, as:

Td = (T1)d.

Therefore,

αd = 1 − (1 − α1)d.

emission: Rgb

Light emitted (not reflected) by the block.

This quantity is the emitted portion of the luminance of this material, in unspecified units where 1.0 is the display white level (except for the effects of tone mapping). In the future this may be redefined in terms of a physical unit, but with the same dimensions.

Because we are describing a volume, not a surface, the physical interpretation of this value depends on the opacity of the material. If self.color.alpha() is 1.0, then this light escaping a surface must have been emitted at the surface; if the alpha is 0.0, then it must have been emitted throughout the volume; and in intermediate cases, then the light emitted within the volume must be greater per unit volume to compensate for internal absorption. Still, these are not distinct cases but form a continuum.

The emission Ed of a particular thickness d of this material is

Ed = E1 · ∫0d (T1)x dx

where E1 = self.emission and T1 = 1.0 - self.color.alpha(). When integrated, this becomes

Ed = E1 · d

when α = 0 (T = 1) and

Ed = E1 · (Td - 1) / (T1 - 1)

otherwise.

collision: BlockCollision

The effect on a Body of colliding with this block.

The default value is BlockCollision::Hard.