Struct all_is_cubes::block::BlockDefTransaction

source ·
pub struct BlockDefTransaction { /* private fields */ }
A Transaction which replaces (or checks) the Block stored in a BlockDef.

Implementations

source

impl BlockDefTransaction

source

pub fn expect(old: Block) -> Self

Returns a transaction which fails if the current value of the BlockDef is not equal to old.

source

pub fn overwrite(new: Block) -> Self

Returns a transaction which replaces the current value of the BlockDef with new.

source

pub fn replace(old: Block, new: Block) -> Self

Returns a transaction which replaces the value of the BlockDef with new, if it is equal to old, and otherwise fails.