#[non_exhaustive]pub struct Move {
pub direction: Face6,
pub distance: u16,
pub velocity: i16,
pub schedule: Schedule,
}Expand description
Data for Modifier::Move; displaces the block out of the grid, cropping it.
A pair of Moves can depict a block moving between two cubes.
Animation
- If the
distanceis zero then the modifier will remove itself, if possible, on the next tick. - If the
distanceandvelocityare such that the block is out of view and will never start being in view, the block will be replaced withAIR.
(TODO: Define the conditions for “if possible”.)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.direction: Face6The direction in which the block is displaced.
distance: u16The distance, in 1/256ths, by which it is displaced.
velocity: i16The amount by which self.distance is changing every time
self.schedule fires.
schedule: ScheduleWhen to apply the velocity.
If self.velocity is zero, this is ignored.
Implementations
Sourceimpl Move
impl Move
Sourcepub fn new(direction: Face6, distance: u16, velocity: i16) -> Self
pub fn new(direction: Face6, distance: u16, velocity: i16) -> Self
TODO: make a cleaner, less internals-ish constructor
Sourcepub fn into_paired(self) -> [Self; 2]
pub fn into_paired(self) -> [Self; 2]
Create a pair of Moves to displace a block.
The first goes on the block being moved, and the second on the air
it’s moving into.
Sourcepub fn complement(&self) -> Self
pub fn complement(&self) -> Self
Calculate the modifier which should be paired with this one, and located at the adjacent
cube pointed to by Self::direction, to produce a complete moving block across two
cubes.
Sourcepub fn rotate(self, rotation: GridRotation) -> Self
pub fn rotate(self, rotation: GridRotation) -> Self
Rotate the movement direction as specified.