pub struct Zoom { /* private fields */ }Expand description
Data for Modifier::Zoom, describing a portion of the original block that is scaled
up to become the whole block.
Design note: This is a struct separate from Modifier so that it can have a
constructor accepting only valid bounds.
Implementations
Sourceimpl Zoom
impl Zoom
Sourcepub fn new(scale: Resolution, offset: GridPoint) -> Self
pub fn new(scale: Resolution, offset: GridPoint) -> Self
Construct a Zoom which enlarges the original block’s voxels by scale and
selects the region of them whose lower corner is offset * scale.
Panics if any of offset’s components are out of bounds, i.e. less than 0 or
greater than scale - 1.
Sourcepub fn scale(&self) -> Resolution
pub fn scale(&self) -> Resolution
Scale factor to zoom in by.