#[non_exhaustive]pub enum Font {
System16,
}Expand description
A font that may be used with Text blocks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
System16
A font whose characteristics are unspecified, other than that it is general-purpose and has a line height (vertical distance from a point on one line to the corresponding point of the next line) of 16 voxels.
This is a placeholder for further improvement in the font system.