#[non_exhaustive]pub enum PositioningX {
Left,
Center,
Right,
}Expand description
How a Text is to be positioned within the layout bounds, along the X axis (horizontally).
A component of Positioning.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Left
Left (most negative X) end of the line of text is positioned at the left edge of the layout bounds.
In the event that RTL text support is added, this is not necessarily the start of the text.
Center
Center the text within the layout bounds.
Right
Right (most positive X) end of the line of text is positioned at the right edge of the layout bounds.
In the event that RTL text support is added, this is not necessarily the end of the text.