#[non_exhaustive]pub enum PositioningY {
BodyTop,
BodyMiddle,
Baseline,
BodyBottom,
}Expand description
How a Text is to be positioned within the layout bounds, along the Y axis (vertically).
A component of Positioning.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BodyTop
The top of a line of text (past which no voxels extend) is aligned with the top edge of the layout bounds.
BodyMiddle
The text is positioned halfway between BodyTop and BodyBottom, centered within the
layout bounds.
This may not necessarily visually center the font, but it will leave the most actually
blank margin.
Baseline
The bottom edge (of most characters, excluding descenders and accents) is positioned at the bottom edge of the layout bounds.
BodyBottom
The bottom of a line of text (past which no voxels extend) is aligned with the bottom edge of the layout bounds.