Positioning

Struct Positioning 

pub struct Positioning {
    pub x: PositioningX,
    pub line_y: PositioningY,
    pub z: PositioningZ,
}
How a Text is to be positioned within a block.

Fields

x: PositioningX

How to place the text horizontally relative to the anchor point.

line_y: PositioningY

How to place the characters of the first line relative to the anchor point.

z: PositioningZ

How to place the text depthwise.

For example, 0 means the voxels will be fill the 0..1 range (in front of the anchor point), and -1 means they will fill the -1..0 range (behind the anchor point).

This is in units of whatever voxel resolution the font itself uses. Therefore, it should not be used for positioning the text overall, but rather for voxel-level effects like engraving vs. embossing.