TextBuilder

Struct TextBuilder 

pub struct TextBuilder { /* private fields */ }
Builder for Text values.

Implementations

Source

impl TextBuilder

pub fn build(self) -> Text

Converts this builder into a Text value.

pub fn string(self, string: ArcStr) -> Self

Sets the string to be displayed.

The string may contain newlines, but is not automatically wrapped beyond that.

The default is the empty string.

pub fn font(self, font: Font) -> Self

Sets the font to use.

The default is Font::System16.

pub fn foreground(self, foreground: Block) -> Self

Sets the “foreground color”, or rather voxel, for the text.

This block is interpreted as a voxel in the same way as a block in a Primitive::Recur space would be. However, the result of evaluating this block not cached. Therefore, it is highly recommended that the block be stored in a block::BlockDef (which does cache) if it is not trivial, particularly if this text is going to span multiple blocks.

The default value is Block::from(all_is_cubes_content::palette::ALMOST_BLACK).

pub fn outline(self, outline: Option<Block>) -> Self

Sets the outline color for the text.

This appears 1 voxel behind and to the side of the main color; making the overall text 2 voxels thick.

See Self::foreground() for information about how the block is used.

The default value is None.

pub fn resolution(self, resolution: Resolution) -> Self

Sets the voxel resolution to use.

This affects the size of the text, including its thickness, and the units of layout_bounds.

The default is 16.

pub fn positioning(self, positioning: Positioning) -> Self

Sets the position of the text within (or extending out of) the layout_bounds.

The default is:

Positioning {
    x: PositioningX::Center,
    line_y: PositioningY::BodyMiddle,
    z: PositioningZ::Back,
}
pub fn layout_bounds(self, resolution: Resolution, bounds: GridAab) -> Self

Sets the voxel bounding box within which the text is positioned, as well as the resolution since that determines the coordinate system scale.

The text might overflow this box; it is currently used only to choose the positioning of the text and cannot constrain it.

pub fn debug(self, debug: bool) -> Self

Sets the debug-rendering flag.

If true, then the text rendering is modified in an unspecified way which is intended to assist in diagnosing issues with text layout configuration. In particular, this currently includes:

  • The region which is in bounds but not filled by a character is filled with a semi-transparent marker color instead of being transparent.
  • If a Primitive::Text block’s bounds fail to intersect its Text, then the block is filled with a marker color.