Cursor

Struct Cursor 

pub struct Cursor { /* private fields */ }
Data collected by cursor_raycast about the blocks struck by the ray; intended to be sufficient for various player interactions with blocks.

Implementations

Source

impl Cursor

pub fn space(&self) -> &Handle<Space>

The space the selected cube is in.

pub fn cube(&self) -> Cube

Which cube of the space that the cursor ray selected/hit.

pub fn preceding_cube(&self) -> Cube

The cube the ray passed through immediately before the selected cube.

This may be the same cube if the ray started there.

pub fn face_selected(&self) -> Face7

Which face of the block the cursor ray selected/hit.

Note that this is not necessarily the same as the face of the enclosing cube, in the case where the block occupies less than the full volume; rather it is intended to make sense to the human who does not get to see the cube grid. It is currently defined to be the hit face of the bounding box of the block data (which is often but not always tightly bounding the visible voxels, so this will have the unsurprising value for any box-shaped block).

Will be Face7::Within if the ray started inside the block.

pub fn hit(&self) -> &CubeSnapshot

Returns data about the cube the cursor selected/hit.