ChunkChart

Struct ChunkChart 

pub struct ChunkChart<const CHUNK_SIZE: GridCoordinate> { /* private fields */ }
Precomputed information about the spherical pattern of chunks within view distance.

In order to use the same pattern for all possible view positions, the view position is rounded to enclosing chunk position.

Implementations

Source

impl<const CHUNK_SIZE: GridCoordinate> ChunkChart<CHUNK_SIZE>

pub fn new(view_distance: FreeCoordinate) -> Self

Constructs a new chart with the given view radius (in blocks).

This function may reuse the calculations from previous calls.

pub fn resize_if_needed(&mut self, view_distance: FreeCoordinate)

Recalculate the chart if the provided distance is different.

pub fn chunks( &self, origin: ChunkPos<CHUNK_SIZE>, mask: OctantMask, ) -> impl DoubleEndedIterator<Item = ChunkPos<CHUNK_SIZE>> + FusedIterator + '_

Returns an iterator over the chunks in this chart — i.e. those intersecting a sphere (or more precisely, the Minkowski sum of a sphere and the chunk) around the given origin chunk.

The chunks are ordered from nearest to farthest in Euclidean distance; the iterator is a DoubleEndedIterator so that Iterator::rev may be used to iterate from farthest to nearest.

mask specifies which directions are in view, in terms of octants of direction vectors. Chunks only visible in directions not in the mask will be culled.