ChunkPos

Struct ChunkPos 

pub struct ChunkPos<const CHUNK_SIZE: GridCoordinate>(pub Cube);
Type to distinguish chunk coordinates from cube coordinates.

Chunk math is generally just like cube math (hence the type of the field), but we don’t want to confuse the two and forget to multiply or divide. A ChunkPos([x, y, z]) identifies the chunk which contains the cubes with x coordinates in the half-open range x * CHUNK_SIZE..(x + 1) * CHUNK_SIZE, and similarly for the y and z axes.

The consequences are unspecified if CHUNK_SIZE is not positive.

Tuple Fields

0: Cube

Implementations

Source

impl<const CHUNK_SIZE: GridCoordinate> ChunkPos<CHUNK_SIZE>

pub const fn new( x: GridCoordinate, y: GridCoordinate, z: GridCoordinate, ) -> Self

Construct a ChunkPos from chunk coordinates (i.e. successive numbers indicate adjacent chunks).

pub fn bounds(self) -> GridAab

Returns the bounds of this chunk as a GridAab.

TODO: specify what happens if the result would overflow.

pub fn distance(self, other: Self) -> Distance

Returns the distance between the two given chunks. See the Distance for an explanation of what that means.

pub fn min_distance_squared_from(self, origin_chunk: Self) -> GridCoordinate

Returns the squared distance along the shortest line from origin_chunk’s bounds to this chunk’s bounds.

This is the same criterion that ChunkChart uses for deciding whether a chunk is included in the chart or not.