pub struct Distance { /* private fields */ }Expand description
A distance between two chunks, taking into consideration their entire volume.
Implements Ord to be comparable as a distance value, with the following properties:
- It matches
ChunkChart’s concept of view distance: the minimum Euclidean distance from any point of two chunks, so that if nothing farther away than D can be seen then this chunk cannot be seen from any point within the origin chunk. - It is usable as a depth sort: chunks sorted by this distance from the chunk containing the eye position will be sorted in back-to-front or front-to-back order.