BlockFault

Enum BlockFault 

#[non_exhaustive]
pub enum BlockFault { TickPrecondition(GridAab), TickConflict(GridAab), }
A subcategory of Fluff: something went wrong with the operation of a block as placed in a Space.

This is not intended for display to all players but as an editor’s diagnostic tool.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TickPrecondition(GridAab)

The block would have executed its BlockAttributes::tick_action operation, but it was prevented due to the operation or transaction preconditions not being met in the given region.



TickConflict(GridAab)

The block would have executed its BlockAttributes::tick_action operation, but another tick action conflicted with it in the given region. This may occur as a normal consequence of e.g. moving structures colliding with each other.