#[non_exhaustive]pub enum ToolError {
NoTool,
NotUsable,
Obstacle,
NothingSelected,
SpaceHandle(HandleError),
Internal(String),
}Expand description
Ways that a tool can fail.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoTool
There was no tool to use (empty inventory slot, nonexistent slot, nonexistent inventory…).
NotUsable
The tool cannot currently be used or does not apply to the target.
Obstacle
Cannot place a block or similar because there’s a block occupying the space.
NothingSelected
The tool requires a target cube and none was present.
SpaceHandle(HandleError)
The space to be operated on could not be accessed.
Internal(String)
An error occurred while executing the effects of the tool.
TODO: Improve this along with Transaction error types.
Implementations