IconRow

Struct IconRow 

pub struct IconRow { /* private fields */ }
Positioning of a displayed row of inventory icons; part of InvInBlock.

Implementations

Source

impl IconRow

pub fn new(slot_range: Range<Ix>, origin: GridPoint, stride: GridVector) -> Self

Constructs an IconRow.

  • slot_range is the the portion of the inventory that is displayed.
  • origin is the lower corner of the location within the voxels where the first slot in slot_range is to be displayed.
  • stride is the translation between adjacent slots.
Panics

Panics if slot_range has end less than start.