pub struct InvInBlock { /* private fields */ }Expand description
Defines how a Modifier::Inventory should be configured and displayed within a Block.
Attach this to a block using block::Builder::inventory_config().
Implementations
Sourceimpl InvInBlock
impl InvInBlock
Sourcepub const EMPTY: Self
pub const EMPTY: Self
Value appropriate for “normal” blocks which should not carry inventories.
Sourcepub fn new(
inventory_size: Ix,
icon_scale: Resolution,
icon_resolution: Resolution,
icon_rows: impl IntoIterator<Item = IconRow>,
) -> Self
pub fn new( inventory_size: Ix, icon_scale: Resolution, icon_resolution: Resolution, icon_rows: impl IntoIterator<Item = IconRow>, ) -> Self
Constructs a InvInBlock.
inventory_sizeis the number of slots the inventory should have.icon_scaleis the scale factor by which to scale down the inventory icon blocks, relative to the bounds of the block in which they are being displayed.icon_resolutionis the maximum resolution of inventory icons, and resolution in which theicon_rows’ position coordinatess are expressed.Modifier::Inventoryis guaranteed not to increase the block resolution beyond this resolution.icon_rowsspecifies where in the block the inventory icons should be displayed. It may be empty in order to keep the inventory invisible.