InventoryTransaction

Struct InventoryTransaction 

pub struct InventoryTransaction { /* private fields */ }
Transaction type for Inventory.

The output type is the change notification which should be passed on after commit, if any change is made.

Implementations

Source

impl InventoryTransaction

pub fn insert<S: Into<Slot>, I: IntoIterator<Item = S>>(stacks: I) -> Self

Transaction to insert items/stacks into an inventory, which will fail if there is not sufficient space.

pub fn replace(slot: Ix, old: Slot, new: Slot) -> Self

Transaction to replace the contents of an existing slot in an inventory, which will fail if the existing slot is not as expected.

TODO: Right now, this requires an exact match. In the future, we should be able to compose multiple modifications like “add 1 item to stack” ×2 into “add 2 items”.

pub fn is_empty(&self) -> bool

Returns whether this transaction does nothing and checks nothing.

Example
use all_is_cubes::inv;

assert!(inv::InventoryTransaction::default().is_empty());

assert!(!inv::InventoryTransaction::insert([inv::Tool::Activate]).is_empty());