ToolInput

Struct ToolInput 

pub struct ToolInput<'ticket> {
    pub read_ticket: ReadTicket<'ticket>,
    pub cursor: Option<Cursor>,
    pub character: Option<Handle<Character>>,
}
Resources available to a Tool to perform its function.

This is intended to provide future extensibility compared to having a complex parameter list for Tool::use_tool.

Fields

read_ticket: ReadTicket<'ticket>

Access to the universe being operated on.

cursor: Option<Cursor>

Cursor identifying block(s) to act on. If None then the tool was used while pointing at nothing or by an agent without an ability to aim.

character: Option<Handle<Character>>

Character that is using the tool.

TODO: We want to be able to express “inventory host”, not just specifically Character (but there aren’t any other examples).

Implementations

Source

impl<'ticket> ToolInput<'ticket>

pub fn cursor(&self) -> Result<&Cursor, ToolError>

Returns a Cursor indicating what blocks the tool should act on, if it is a sort of tool that acts on blocks. If there is no Cursor, because of aim or because of being used in a context where there cannot be any aiming, returns Err(ToolError::NothingSelected) for convenient propagation.

pub fn produce_items<S: Into<Slot>, I: IntoIterator<Item = S>>( &self, items: I, ) -> Result<UniverseTransaction, ToolError>

Add the provided items to the inventory from which the tool was used.