Axis

Enum Axis 

#[repr(u8)]
pub enum Axis { X = 0, Y = 1, Z = 2, }
Enumeration of the axes of three-dimensional space.

Can be used to infallibly index 3-component arrays and vectors.

See also:

  • Face6 specifies an axis and a direction on the axis.

Variants



X = 0



Y = 1



Z = 2

Implementations

Source

impl Axis

pub const ALL: [Axis; 3]

All three axes in the standard order, [X, Y, Z].

pub fn color(self) -> Rgb01

Returns a standard color to denote this axis among the three axes. All colors have equal luminance.

  • X = red
  • Y = green
  • Z = blue
pub fn positive_face(self) -> Face6

Returns the Face6 value which corresponds to the positive direction on this axis.

pub fn negative_face(self) -> Face6

Returns the Face6 value which corresponds to the negative direction on this axis.

pub const fn index(self) -> usize

Convert the axis to a number for indexing 3-element arrays.

pub const fn increment(self) -> Axis

Maps X to Y, Y to Z, and Z to X.

pub const fn decrement(self) -> Axis

Maps X to Z, Y to X, and Z to Y.