Face6

Enum Face6 

#[repr(u8)]
pub enum Face6 { NX = 1, NY = 2, NZ = 3, PX = 4, PY = 5, PZ = 6, }
Identifies a face of a cube or an orthogonal unit vector.

See also the similar type Face7, which adds a “zero” or “within the cube” variant. The two enums use the same discriminant numbering.

Serialization stability warning

This type implements serde::Serialize and serde::Deserialize, but serialization support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes will be able to deserialize data which is serialized by this version.

Additionally, the serialization schema is designed with serde_json in mind. It is not guaranteed that using a different data format crate, which may use a different subset of the information exposed via serde::Serialize, will produce stable results.

Variants



NX = 1

Negative X; the face whose normal vector is (-1, 0, 0).



NY = 2

Negative Y; the face whose normal vector is (0, -1, 0); downward.



NZ = 3

Negative Z; the face whose normal vector is (0, 0, -1).



PX = 4

Positive X; the face whose normal vector is (1, 0, 0).



PY = 5

Positive Y; the face whose normal vector is (0, 1, 0); upward.



PZ = 6

Positive Z; the face whose normal vector is (0, 0, 1).

Implementations

Source

impl Face6

pub const ALL: [Face6; 6]

All the values of Face6.

pub const fn from_discriminant(d: u8) -> Option<Face6>

Inverse function of face as u8, converting the number to Face6.

pub fn from_snapped_vector(vector: Vector3D<f64, Cube>) -> Option<Face6>

Returns the Face6 whose normal vector is closest in direction to the given vector.

Edge cases:

  • Ties are broken by preferring Z faces over Y faces, and Y faces over X faces.
  • If all magnitudes are zero, the Z axis’s sign is used. (Remember that floating-point numbers include distinct positive and negative zeroes).
  • If any coordinate is NaN, returns None.
pub const fn axis(self) -> Axis

Returns which axis this face’s normal vector is parallel to.

pub const fn is_positive(self) -> bool

Returns whether this face is a “positive” face: one whose unit vector’s nonzero coordinate is positive.

use all_is_cubes::math::Face6;

assert_eq!(Face6::PX.is_positive(), true);
assert_eq!(Face6::NX.is_positive(), false);
pub fn is_negative(self) -> bool

Returns whether this face is a negative face: one whose unit vector’s nonzero coordinate is negative.

use all_is_cubes::math::Face6;

assert_eq!(Face6::PX.is_negative(), false);
assert_eq!(Face6::NX.is_negative(), true);
pub const fn opposite(self) -> Face6

Returns the opposite face (maps PX to NX and so on).

pub const fn cross(self, other: Face6) -> Face7

Returns the face whose normal is the cross product of these faces’ normals. Since cross products may be zero, the result is a Face7.

pub fn normal_vector<S, U>(self) -> Vector3D<S, U>
where S: Zero + One + Neg<Output = S>,

Returns the axis-aligned unit vector normal to this face.

If a vector of a different length is desired, use Face6::vector() instead of multiplying this.

pub fn vector<S, U>(self, magnitude: S) -> Vector3D<S, U>
where S: Zero + Neg<Output = S>,

Returns an axis-aligned vector normal to this face, whose magnitude, and only nonzero component, is magnitude.

This is mathematically equivalent to multiplying Face6::normal_vector() by magnitude, but does not perform those multiplications, and may have better type inference.

Example
use all_is_cubes::math::{Face6, GridVector};

assert_eq!(Face6::PY.vector(3), GridVector::new(0, 3, 0));
assert_eq!(Face6::NY.vector(3), GridVector::new(0, -3, 0));
pub fn dot<S, U>(self, vector: Vector3D<S, U>) -> S
where S: Zero + Neg<Output = S>,

Dot product of this face as a unit vector and the given vector, implemented by selecting the relevant component.

use all_is_cubes::math::{Face6, FreeVector};

let sample_vector = FreeVector::new(1.0, 2.0, 5.0_f64);
for face in Face6::ALL {
    assert_eq!(face.dot(sample_vector), face.normal_vector().dot(sample_vector));
}
pub const fn rotation_from_nz(self) -> GridRotation

Returns a rotation, without reflection, which will rotate Face6::NZ to be self.

The significance of this rotation is that it may be used to obtain a set of coordinate systems for all six faces of some cube. It is arbitrary, but convenient to have the arbitrary choice already made.

pub const fn face_transform(self, scale: i32) -> Gridgid

Returns a Gridgid transformation which, if given points on the square with x ∈ [0, scale], y ∈ [0, scale], and z = 0, converts them to points that lie on the faces of the cube with x ∈ [0, scale], y ∈ [0, scale], and z ∈ [0, scale].

Specifically, Face6::NZ.face_transform() is the identity and all others are consistent with that. Note that there are arbitrary choices in the rotation of all other faces. (TODO: Document those choices and test them.)

The rotations used are equal to Face6::rotation_from_nz(), and this method is equivalent to self.rotation_from_nz().to_positive_octant_transform(scale).

To work with floating-point coordinates, use .face_transform().to_matrix().to_free().

pub const fn clockwise(self) -> GridRotation

Returns the rotation which is clockwise, when looking towards the face self of the rotated object.

Example
use all_is_cubes::math::Face6::*;

assert_eq!(PY.clockwise().transform(PX), PZ);
pub const fn counterclockwise(self) -> GridRotation

Returns the rotation which is counterclockwise (anticlockwise), when looking towards the face self of the rotated object.

Example
use all_is_cubes::math::Face6::*;

assert_eq!(PY.counterclockwise().transform(PZ), PX);
pub const fn r180(self) -> GridRotation

Returns the rotation which is a half turn or 180º, when looking towards the face self of the rotated object.

This result only depends on the axis, not the direction, but it is available here to complete the set [self, self.clockwise(), self.r180(), self.counterclockwise()], which can also be expressed as self.clockwise().iterate().

Example
use all_is_cubes::math::Face6::*;

assert_eq!(PY.r180().transform(PX), NX);