Octant

Enum Octant 

#[repr(u8)]
pub enum Octant { Nnn = 0, Nnp = 1, Npn = 2, Npp = 3, Pnn = 4, Pnp = 5, Ppn = 6, Ppp = 7, }
Identifies one of eight octants, or elements of a 2×2×2 cube.

Used with OctantMask and OctantMap.

This enum’s discriminants are not currently to be considered stable; they may be reordered.

Variants



Nnn = 0

The -X, -Y, -Z octant.



Nnp = 1

The -X, -Y, +Z octant.



Npn = 2

The -X, +Y, -Z octant.



Npp = 3

The -X, +Y, +Z octant.



Pnn = 4

The +X, -Y, -Z octant.



Pnp = 5

The +X, -Y, +Z octant.



Ppn = 6

The +X, +Y, -Z octant.



Ppp = 7

The +X, +Y, +Z octant.

Implementations

Source

impl Octant

pub const ALL: [Octant; 8]

All values of the enum.

pub fn try_from_positive_cube(cube: Cube) -> Option<Octant>

Given a cube in the volume (0..2)³, return which octant of that volume it is.

pub fn try_from_01<T, U>( corner_or_translation: Vector3D<T, U>, ) -> Option<Octant>
where T: Copy + NumCast,

Given the low corner of an octant in the volume (0..2)³, return which octant it is.

That is, each coordinate of the returned Vector3D is either 0 or 1. This is equivalent to Self::try_from_positive_cube() but with more flexible input.

TODO: better trait bounds would be Zero + One

pub fn from_vector(vector: Vector3D<f64, Cube>) -> Octant

Returns the octant the given vector points toward, when interpreted as pointing away from the center point where all octants meet.

Ties due to zero components are broken in the positive direction.

pub fn to_positive_cube(self) -> Cube

Returns this octant of the volume (0..2)³.

That is, each coordinate of the returned Cube is either 0 or 1.

pub fn to_01<U>(self) -> Vector3D<u8, U>

Returns this octant of the volume (0..2)³ expressed as a translation vector from the origin.

That is, each coordinate of the returned Vector3D is either 0 or 1.

pub fn reflect<T, U>(self, vector: Vector3D<T, U>) -> Vector3D<T, U>
where T: Neg<Output = T>,

For each component of vector, negate it if self is on the negative side of that axis.

This may be used to transform between positive-octant-only data and data mirrored into arbitrary octants.