CubeFace

Struct CubeFace 

pub struct CubeFace {
    pub cube: Cube,
    pub face: Face7,
}
The combination of a Cube and Face7 identifying one face of it or the interior. This pattern appears in cursor selection and collision detection.

Fields

cube: Cubeface: Face7

Implementations

Source

impl CubeFace

pub fn new(cube: impl Into<Cube>, face: Face7) -> CubeFace

pub fn adjacent(self) -> Cube

Computes the cube that is adjacent in the direction of self.face. Equal to self.cube if the face is Face7::Within.

May panic if the cube coordinates overflow.

pub fn translate(self, offset: Vector3D<i32, Cube>) -> CubeFace

Translate self by adding offset to self.cube.