OctantMask

Struct OctantMask 

pub struct OctantMask { /* private fields */ }
A set of Octants (or equivalently, one bool for each cube of a 2×2×2 volume).

Internally represented as a u8 bit-set.

This type may be used for culling or other calculations relating to the axis-aligned volumes surrounding a point. If more data than bool is needed, use OctantMap.

Implementations

Source

impl OctantMask

pub const ALL: OctantMask

The mask including all octants (all bits set).

pub const NONE: OctantMask

The mask including no octants (no bits set).

pub fn get(self, octant: Octant) -> bool

Get the flag for the given octant.

pub fn set(&mut self, octant: Octant)

Set the flag for the given octant.

pub fn clear(&mut self, octant: Octant)

Clear the flat for the given octant.

pub fn shift(self, direction: Face6) -> OctantMask

Shift the data in the specified direction, discarding overflows and filling with false/clear.