PositiveSign

Struct PositiveSign 

pub struct PositiveSign<T>(/* private fields */);
A floating-point number which is not NaN and whose sign bit is positive.

The allowed values consist of positive zero, positive infinity, and every value in between those. This set of values means that this type:

  • Implements Eq straightforwardly; neither NaN nor signed zeroes can cause problems with using it as a map key for caching, interning, etc.
  • Is closed under multiplication and addition, so unlike NotNan, cannot cause a panic from uncautious arithmetic.

The permitted values of a PositiveSign<T> are a subset of those of a NotNan<T>. (This may not be guaranteed if T implements numeric traits in inconsistent ways, but may be assumed for f32 and f64.)

The arithmetic behavior of PositiveSign<T> is not identical to T. Specifically, the value of 0. * fXX::INFINITY is NaN, but the value of PositiveSign(0.) * PositiveSign(fXX::INFINITY) is PositiveSign(0.) instead. Our assumption here is that for the applications where PositiveSign is suitable, infinities are either impossible or arise as “would be finite but it is too large to be represented”, and do not arise as the reciprocal of zero, and thus we can treat “zero times anything is zero” as being a more important property than “infinity times anything is infinity”.

Implementations

Source

impl<T> PositiveSign<T>
where T: FloatCore,

pub const unsafe fn new_unchecked(value: T) -> PositiveSign<T>

Construct PositiveSign without checking the value.

Safety

value must not be NaN and must have a positive sign bit. Note that value >= 0. is not a sufficient condition, because it does not exclude negative zero.

pub const fn into_inner(self) -> T

Unwraps the value without modifying it.

pub fn floor(self) -> PositiveSign<T>

Returns the largest integer less than or equal to self.

pub fn ceil(self) -> PositiveSign<T>

Returns the smallest integer greater than or equal to self.

pub fn round(self) -> PositiveSign<T>

Returns the nearest integer to self. If a value is half-way between two integers, round up from 0.0.

pub fn is_finite(&self) -> bool

Returns whether the value is finite.

Since the value is statically guaranteed to be neither NaN nor negative, the only case where this returns false is when the value is positive infinity.

pub fn clamp_01(self) -> ZeroOne<T>

Convert to ZeroOne, replacing too-large values with 1.0.

Source

impl PositiveSign<f32>

pub const INFINITY: PositiveSign<f32>

Positive infinity (∞).

pub const fn new_strict(value: f32) -> PositiveSign<f32>

Wraps the given value in PositiveSign.

  • If value is positive (including positive infinity), returns wrapped value.
  • If value is zero of either sign, returns wrapped positive zero. This is lossy, but corresponds to the IEEE 754 idea that -0.0 == +0.0.
  • If value is negative non-zero or NaN, panics.
pub const fn new_clamped(value: f32) -> PositiveSign<f32>

Wraps the given value in PositiveSign.

  • If the value is NaN, panics.
  • If the value has a negative sign, it is replaced with positive zero.
pub fn saturating_sub(self, other: PositiveSign<f32>) -> PositiveSign<f32>

Subtract other from self; if the result would be negative, it is zero instead.

Source

impl PositiveSign<f64>

pub const INFINITY: PositiveSign<f64>

Positive infinity (∞).

pub const fn new_strict(value: f64) -> PositiveSign<f64>

Wraps the given value in PositiveSign.

  • If value is positive (including positive infinity), returns wrapped value.
  • If value is zero of either sign, returns wrapped positive zero. This is lossy, but corresponds to the IEEE 754 idea that -0.0 == +0.0.
  • If value is negative non-zero or NaN, panics.
pub const fn new_clamped(value: f64) -> PositiveSign<f64>

Wraps the given value in PositiveSign.

  • If the value is NaN, panics.
  • If the value has a negative sign, it is replaced with positive zero.
pub fn saturating_sub(self, other: PositiveSign<f64>) -> PositiveSign<f64>

Subtract other from self; if the result would be negative, it is zero instead.