ZeroOne

Struct ZeroOne 

pub struct ZeroOne<T>(/* private fields */);
A floating-point number which is within the range +0 to +1 (inclusive).

This may be used for alpha blending, reflectance, lerps, and anything else where values outside the range 0 to 1 is meaningless. It is closed under multiplication.

Because NaN and negative zero are excluded, this type implements Eq straightforwardly, and can reliably be used as a map key for caching, interning, etc.

Implementations

Source

impl<T> ZeroOne<T>
where T: FloatCore,

pub const unsafe fn new_unchecked(value: T) -> ZeroOne<T>

Construct ZeroOne without checking the value.

Safety

value must be +0, 1, or some value in between those two. Note that value >= 0. && value <= 1. is not a sufficient condition, because it does not exclude negative zero.

pub const fn into_inner(self) -> T

Unwraps the value without modifying it.

pub fn complement(self) -> ZeroOne<T>

Returns 1.0 - self.

The result cannot be out of range, so this operation is always successful.

Source

impl<T> ZeroOne<T>

pub const ZERO: ZeroOne<T>

The number zero, as a constant.

pub const ONE: ZeroOne<T>

The number one, as a constant.

Source

impl ZeroOne<f32>

pub const fn new_strict(value: f32) -> ZeroOne<f32>

Wraps the given value in ZeroOne.

  • If value is in range, returns wrapped value.
  • If value is zero of either sign, returns wrapped positive zero. This is lossy, but corresponds to the IEEE 754 idea that -0.0 == +0.0.
  • If value is out of range or NaN, panics.
pub const fn new_clamped(value: f32) -> ZeroOne<f32>

Wraps the given value in ZeroOne.

  • If the value is NaN, panics.
  • If the value is out of range, replaces it with the nearest in-range value (0 or 1).
pub const fn is_zero(self) -> bool

Const version of self == ZeroOne::ZERO

pub const fn is_one(self) -> bool

Const version of self == ZeroOne::ONE

Source

impl ZeroOne<f64>

pub const fn new_strict(value: f64) -> ZeroOne<f64>

Wraps the given value in ZeroOne.

  • If value is in range, returns wrapped value.
  • If value is zero of either sign, returns wrapped positive zero. This is lossy, but corresponds to the IEEE 754 idea that -0.0 == +0.0.
  • If value is out of range or NaN, panics.
pub const fn new_clamped(value: f64) -> ZeroOne<f64>

Wraps the given value in ZeroOne.

  • If the value is NaN, panics.
  • If the value is out of range, replaces it with the nearest in-range value (0 or 1).
pub const fn is_zero(self) -> bool

Const version of self == ZeroOne::ZERO

pub const fn is_one(self) -> bool

Const version of self == ZeroOne::ONE