Body

Struct Body 

#[non_exhaustive]
pub struct Body { pub flying: bool, pub noclip: bool, pub yaw: FreeCoordinate, pub pitch: FreeCoordinate, /* private fields */ }
An object with a position, velocity, and collision volume. What it collides with is determined externally.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
flying: bool

Is this body not subject to gravity?

noclip: bool

Is this body not subject to collision?

yaw: FreeCoordinate

Yaw of the camera look direction, in degrees clockwise from looking towards -Z.

The preferred range is 0 inclusive to 360 exclusive.

This does not affect the behavior of the Body itself; it has nothing to do with the direction of the velocity.

pitch: FreeCoordinate

Pitch of the camera look direction, in degrees downward from looking horixontally.

The preferred range is -90 to 90, inclusive.

This does not affect the behavior of the Body itself; it has nothing to do with the direction of the velocity.

Implementations

Source

impl Body

pub fn new_minimal( position: impl Into<FreePoint>, collision_box: impl Into<Aab>, ) -> Self

Constructs a Body requiring only information that can’t be reasonably defaulted.

Panics

Panics if any component of position is NaN or infinite.

pub fn position(&self) -> FreePoint

Returns the body’s current position.

If you are interested in the space it occupies, use Self::collision_box_abs() instead.

pub fn set_position(&mut self, position: FreePoint)

Sets the position of the body, disregarding collision.

Note: This may have effects that normal time stepping does not. In particular, body.set_position(body.position()) is not guaranteed to do nothing.

If position contains any component which is infinite or NaN, this function does nothing. This behavior may change in the future.

pub fn velocity(&self) -> Vector3D<f64, Velocity>

Returns the body’s current velocity.

pub fn add_velocity(&mut self, Δv: Vector3D<f64, Velocity>)

Adds the given value to the body’s velocity.

If Δv contains any component which is infinite or NaN, this function does nothing. This behavior may change in the future.

pub fn set_velocity(&mut self, v: Vector3D<f64, Velocity>)

Replaces the body’s velocity with the given value.

If Δv contains any component which is infinite or NaN, this function does nothing. This behavior may change in the future.

pub fn collision_box_rel(&self) -> Aab

Returns the body’s configured collision box in coordinates relative to Self::position().

use all_is_cubes::math::Aab;
use all_is_cubes::physics::Body;

let body = Body::new_minimal(
    (0.0, 20.0, 0.0),
    Aab::new(-1.0, 1.0, -2.0, 2.0, -3.0, 3.0)
);
assert_eq!(body.collision_box_abs(), Aab::new(-1.0, 1.0, 18.0, 22.0, -3.0, 3.0));
pub fn collision_box_abs(&self) -> Aab

Returns the body’s current collision box in world coordinates.

This is not necessarily equal in size to Self::collision_box_rel().

use all_is_cubes::math::Aab;
use all_is_cubes::physics::Body;

let body = Body::new_minimal(
    (0.0, 20.0, 0.0),
    Aab::new(-1.0, 1.0, -2.0, 2.0, -3.0, 3.0)
);
assert_eq!(body.collision_box_abs(), Aab::new(-1.0, 1.0, 18.0, 22.0, -3.0, 3.0));
pub fn look_direction(&self) -> FreeVector

Returns the direction the body is facing (when it is part of a character).

pub fn set_look_direction(&mut self, direction: FreeVector)

Changes self.yaw and self.pitch to look in the given direction vector.

If direction has zero length, the resulting direction is unspecified but valid.