Struct all_is_cubes::physics::BodyStepInfo
source · #[non_exhaustive]pub struct BodyStepInfo {
pub quiescent: bool,
pub push_out: Option<FreeVector>,
pub already_colliding: Option<Contact>,
pub move_segments: [MoveSegment; 3],
/* private fields */
}Expand description
Diagnostic data returned by Body::step(). The exact contents of this structure
are unstable; use only Debug formatting to examine its contents unless you have
a specific need for one of the values.
Note: Unlike most *StepInfo types, this one cannot be meaningfully aggregated,
because it contains specific spatial details of the body step.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quiescent: boolWhether movement computation was skipped due to approximately zero velocity.
push_out: Option<FreeVector>already_colliding: Option<Contact>move_segments: [MoveSegment; 3]Details on movement and collision. A single frame’s movement may have up to three segments as differently oriented faces are collided with.