SoundDef

Struct SoundDef 

#[non_exhaustive]
pub struct SoundDef { pub duration: ZeroOne<f32>, pub frequency: PositiveSign<f32>, pub amplitude: ZeroOne<f32>, }
A sound effect or grain.

SoundDefs are used as members of Universes and may be referenced by … TODO document

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
duration: ZeroOne<f32>

The total duration of the sound, in seconds. It may not be longer than one second.

frequency: PositiveSign<f32>

The frequency of the oscillator, in hertz.

amplitude: ZeroOne<f32>

TODO: Define amplitude scaling. We probably need some physical reference because the obvious alternative, 0 dBFS, is a bad idea. But some sounds are spatial and some are not…perhaps “1 meter/cube away is the reference distance” will solve that.