pub struct ActivatableRegion {
pub effect: EphemeralOpaque<dyn Fn() + Send + Sync>,
}Expand description
A region of a Space that does something if Tool::Activate is used on it.
TODO: This is a placeholder for a better design; it’s too specific (external side effect) and yet also not general enough (we would like buttons to have detailed reactions to clicking) considering that it’s hardcoded in Space.
Fields
effect: EphemeralOpaque<dyn Fn() + Send + Sync>The function to call when this region is activated.
Implementations