CubeTransaction

Struct CubeTransaction 

pub struct CubeTransaction { /* private fields */ }
A modification to the contents of single cube of a Space.

To make use of this, insert it into a SpaceTransaction to specify which cube is modified. This type does not function directly as a Transaction (though it does implement Merge).

Implementations

Source

impl CubeTransaction

pub fn at(self, cube: Cube) -> SpaceTransaction

Creates a SpaceTransaction that applies self to the given cube of the space.

pub fn replacing(old: Option<Block>, new: Option<Block>) -> Self

Construct a CubeTransaction that may check and may replace the block in the cube.

If old is not None, requires that the existing block is that block or the transaction will fail. If new is not None, replaces the existing block with new.

pub fn overwrite(&mut self, block: Block)

Sets the block to be placed at this cube, replacing any existing modification instruction This does not affect a precondition on the existing block, or the conservative option.

This is thus comparable to the effect of a direct Mutation::set() after the rest of the transaction.

pub fn fluff(fluff: Fluff) -> Self

Emit Fluff (sound/particle effects) at this cube when the transaction is committed.

pub fn add_fluff(&mut self, fluff: Fluff)

Emit Fluff (sound/particle effects) at this cube when the transaction is committed, in addition to its other effects.