SpaceBehaviorAttachment

Struct SpaceBehaviorAttachment 

pub struct SpaceBehaviorAttachment { /* private fields */ }
Description of where in a Space a Behavior<Space> exists.

Implementations

Source

impl SpaceBehaviorAttachment

pub fn new(bounds: GridAab) -> Self

Constructs a new SpaceBehaviorAttachment with no rotation.

pub fn bounds(&self) -> GridAab

Returns the bounds of this attachment, which specify (without mandating) what region the behavior should affect.

pub fn rotation(&self) -> GridRotation

Returns the rotation of this attachment, which specifies, if applicable, which orientation the behavior should operate in relative to the space. The exact meaning of this is up to the behavior.

TODO: explain with an example once we have a good one