Struct all_is_cubes::space::SpaceBlockData
source · pub struct SpaceBlockData { /* private fields */ }Expand description
Information about the interpretation of a block index.
Design note: This doubles as an internal data structure for Space. While we’ll
try to keep it available, this interface has a higher risk of needing to change
incompatibility.
Implementations
sourceimpl SpaceBlockData
impl SpaceBlockData
sourcepub const NOTHING: Self = _
pub const NOTHING: Self = _
A SpaceBlockData value used to represent out-of-bounds or placeholder
situations. The block is AIR and the count is always zero.
sourcepub fn evaluated(&self) -> &EvaluatedBlock
pub fn evaluated(&self) -> &EvaluatedBlock
Returns the EvaluatedBlock representation of the block.
TODO: Describe when this may be stale.