SpaceStepInfo

Struct SpaceStepInfo 

#[non_exhaustive]
pub struct SpaceStepInfo { pub spaces: usize, pub evaluations: TimeStats, pub light: LightUpdatesInfo, /* private fields */ }
Performance data about stepping a Space.

The exact contents of this structure are unstable; use only Debug formatting to examine its contents unless you have a specific need for one of the values.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
spaces: usize

Number of spaces whose updates were aggregated into this value.

evaluations: TimeStats

Time and count of block re-evaluations.

Note that this does not count evaluations resulting from modifications that add new blocks to the space.

light: LightUpdatesInfo

Performance data about light updates within the space.