pub struct Schedule { /* private fields */ }Expand description
Specifies which Ticks a repeating event occurs on.
Implementations
Sourceimpl Schedule
impl Schedule
Sourcepub const EVERY_TICK: Self
pub const EVERY_TICK: Self
Schedule which includes every tick.
Sourcepub fn from_period(period: NonZeroU16) -> Self
pub fn from_period(period: NonZeroU16) -> Self
Creates a schedule which specifies executing some action every period ticks.
The period should be divisible by the universe’s TickSchedule’s divisor.
If it is not, then schedule will have uneven periods.
If it is zero, it will be replaced with 1.
Sourcepub fn to_period(self) -> Option<NonZeroU16>
pub fn to_period(self) -> Option<NonZeroU16>
If this schedule is of the form “every N ticks”, return N.