#[non_exhaustive]pub struct TimeStats {
pub count: usize,
pub sum: Duration,
pub min: Option<Duration>,
pub max: Duration,
}Expand description
Summary of the time taken by a set of events.
This type is produced by performance measurements within several subsystems of All is Cubes.
It may be created by TimeStats::default() (empty), or TimeStats::one() (single event),
and multiple events may be aggregated using the += operator.
It may be formatted for reading using the fmt::Display implementation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.count: usizeThe number of events aggregated into this TimeStats.
sum: DurationThe sum of the durations of all events.
min: Option<Duration>The minimum duration of all events, or None if there were no events.
max: DurationThe maximum duration of all events, or Duration::ZERO if there were no events.
Implementations