pub enum ExecuteError<Txn: Transaction = UniverseTransaction> {
Merge(<Txn as Merge>::Conflict),
Check(<Txn as Transaction>::Mismatch),
Commit(CommitError),
Handle(HandleError),
}Expand description
Error type from Transaction::execute() and Transactional::transact().
Variants
Merge(<Txn as Merge>::Conflict)
A conflict was discovered between parts that were to be assembled into the transaction.
This error cannot be produced by Transaction::execute(), but only by
Transactional::transact().
Check(<Txn as Transaction>::Mismatch)
The transaction’s preconditions were not met; it does not apply to the current state of the target. No change has been made.
Commit(CommitError)
An unexpected error occurred while applying the transaction’s effects.
See the documentation of Transaction::commit() for the unfortunate
implications of this.
Handle(HandleError)
Executing the transaction required accessing a Handle that was unavailable.
The HandleError will include the name of the problematic handle.
This error may be transient, and
unlike ExecuteError::Commit, does not indicate data corruption,
but code which triggers it should generally be considered incorrect.
Note that not all cases of failure due to handle access will return this error;
those means of transaction execution which are specifically asked to
act on a handle do, whereas handles read during the check phase will produce
ExecuteError::Check, and so on. This may change in the future.