CommitError

Struct CommitError 

pub struct CommitError(/* private fields */);
Type of “unexpected errors” from Transaction::commit().

Implementations

Source

impl CommitError

pub fn catch<T, E: Error + Send + Sync + 'static>(error: E) -> Self

Wrap an arbitrary unexpected error as a CommitError. T should be the type of the transaction that caught it.

pub fn message<T>(message: String) -> Self

Construct a CommitError with a string description. T should be the type of the transaction that detected the problem.

pub fn context(self, component: String) -> Self

Report an error propagating up from an inner transaction. component should describe which part of the current transaction returned the error from its commit().