Struct all_is_cubes::util::ConciseDebug

source ·
pub struct ConciseDebug;
Format type for manyfmt::Fmt which is similar to fmt::Debug, but uses an alternate concise format.

This format may be on one line despite the pretty-printing option, and may lose precision or Rust syntax in favor of a short at-a-glance representation.