pub struct BehaviorSet<H: Host> { /* private fields */ }Expand description
Collects Behaviors and invokes them.
Note: This type is public out of necessity because it is revealed elsewhere, but its details are currently subject to change.
To modify the set, use a BehaviorSetTransaction.
Serialization stability warning
This type implements serde::Serialize and serde::Deserialize, but serialization
support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes
will be able to deserialize data which is serialized by this version.
Additionally, the serialization schema is designed with serde_json in mind. It is not
guaranteed that using a different data format crate, which may use a different subset of
the information exposed via serde::Serialize, will produce stable results.
Implementations
Sourceimpl<H: Host> BehaviorSet<H>
impl<H: Host> BehaviorSet<H>
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs an empty BehaviorSet.
Sourcepub fn query<T: Behavior<H>>(
&self,
) -> impl Iterator<Item = QueryItem<'_, H, T>> + '_
pub fn query<T: Behavior<H>>( &self, ) -> impl Iterator<Item = QueryItem<'_, H, T>> + '_
Find behaviors of a specified type.
The behaviors will be returned in a deterministic order. In the current implementation, that order is the order in which they were added.
TODO: Allow querying by attachment details (spatial, etc)
Sourcepub fn query_any<'a>(
&'a self,
type_filter: Option<TypeId>,
) -> impl Iterator<Item = QueryItem<'a, H, dyn Behavior<H> + 'static>> + 'a
pub fn query_any<'a>( &'a self, type_filter: Option<TypeId>, ) -> impl Iterator<Item = QueryItem<'a, H, dyn Behavior<H> + 'static>> + 'a
Find behaviors by filter criteria. All Nones mean “anything”.
The behaviors will be returned in a deterministic order. In the current implementation, that order is the order in which they were added.
TODO: Allow querying by attachment details (spatial, etc)