Struct all_is_cubes::behavior::BehaviorSetTransaction
source · pub struct BehaviorSetTransaction<H: BehaviorHost> { /* private fields */ }Expand description
A Transaction that adds or modifies Behaviors in a BehaviorSet.
Implementations
sourceimpl<H: BehaviorHost> BehaviorSetTransaction<H>
impl<H: BehaviorHost> BehaviorSetTransaction<H>
sourcepub fn insert(attachment: H::Attachment, behavior: Arc<dyn Behavior<H>>) -> Self
pub fn insert(attachment: H::Attachment, behavior: Arc<dyn Behavior<H>>) -> Self
Constructs a transaction that adds a behavior to the behavior set.