Struct all_is_cubes::behavior::QueryItem

source ·
#[non_exhaustive]
pub struct QueryItem<'a, H: BehaviorHost, B: Behavior<H> + ?Sized> { pub behavior: &'a B, pub attachment: &'a H::Attachment, }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
behavior: &'a B

The found behavior’s current value.

attachment: &'a H::Attachment

The found behavior’s current attachment.

An attachment is additional data about “where” the behavior is attached to the host what part of the host should be affected by the behavior.