#[non_exhaustive]pub enum BlockCollision {
None,
Hard,
}Expand description
Specifies the effect on a Body of colliding with a
Primitive::Atom block or voxel having this property.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
The atom can be passed through; it is not an obstacle (though intersecting it might cause other effects not directly part of collision response).
Hard
The atom is a perfectly solid obstacle occupying its entire bounding cube.
This is the default value used for most blocks.