Enum all_is_cubes::block::EvalBlockError
source · #[non_exhaustive]pub enum EvalBlockError {
BudgetExceeded {
budget: Cost,
used: Cost,
},
PriorBudgetExceeded {
budget: Cost,
used: Cost,
},
Handle(HandleError),
}Expand description
Errors resulting from Block::evaluate().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BudgetExceeded
The evaluation budget was exceeded.
Fields
PriorBudgetExceeded
The evaluation budget was exceeded, in a previous cached evaluation. rather than the current one (so the current evaluation’s budget could not have affected the outcome).
Fields
Handle(HandleError)
The block definition contained a Handle which was not currently available to read.
This may be temporary or permanent; consult the HandleError to determine that.
Implementations
sourceimpl EvalBlockError
impl EvalBlockError
sourcepub fn to_placeholder(&self) -> EvaluatedBlock
pub fn to_placeholder(&self) -> EvaluatedBlock
Convert this error into an EvaluatedBlock which represents that an error has
occurred.
This block is fully opaque and as inert to game mechanics as currently possible.