Enum all_is_cubes::block::Resolution

source ·
#[non_exhaustive]
#[repr(u8)]
pub enum Resolution { R1 = 0, R2 = 1, R4 = 2, R8 = 3, R16 = 4, R32 = 5, R64 = 6, R128 = 7, }
Scale factor between a Block and its component voxels.

This resolution cubed is the number of voxels making up a block.

Resolutions are always powers of 2. This ensures that the arithmetic is well-behaved (no division by zero, exact floating-point representation, and the potential of fixed-point representation), and that it is always possible to subdivide a block further (up to the limit) without shifting the existing voxel boundaries.

Note that while quite high resolutions are permitted, this does not mean that it is practical to routinely use full blocks at that resolution. For example, 64 × 64 × 64 = 262,144 voxels, occupying several megabytes just for color data. High resolutions are permitted for special purposes that do not necessarily use the full cube volume:

  • Thin blocks (e.g. 128 × 128 × 1) can display high resolution text and other 2D images.
  • Multi-block structures can be defined using Modifier::Zoom; their total size is limited by the resolution limit.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


R1 = 0



R2 = 1



R4 = 2



R8 = 3



R16 = 4



R32 = 5



R64 = 6



R128 = 7

Implementations

source

impl Resolution

source

pub const MAX: Resolution = Resolution::R128

The maximum available resolution.

source

pub const fn double(self) -> Option<Resolution>

Returns the Resolution that’s twice this one, or None at the limit.

source

pub const fn halve(self) -> Option<Resolution>

Returns the Resolution that’s half this one, or None if self is R1.