#[non_exhaustive]pub struct AnimationHint {
pub redefinition: AnimationChange,
pub replacement: AnimationChange,
}Expand description
Specifies how a Block might change in the very near future, for the benefit
of rendering algorithms. Does not currently describe non-visual aspects of a block.
This should be configured for blocks which either are continuously animated in some fashion, or for which it is especially important that the specified changes are handled efficiently, at the possible cost of spending more resources on those blocks. Blocks which merely might change in response to user action should not set this hint.
The | operator may be used to combine multiple hints into “both of these will happen”.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.redefinition: AnimationChangeWays in which the block’s definition might change (via modification to a
BlockDef or recursive Space) such that many instances of this block
will become another simultaneously.
replacement: AnimationChangeIf this block is likely to be replaced in a Space by another, this field
specifies the replacement’s relation to this.
Implementations
Sourceimpl AnimationHint
impl AnimationHint
Sourcepub const UNCHANGING: Self
pub const UNCHANGING: Self
There are no expectations that the block is soon going to change.
This is the default value of this type and within BlockAttributes.
Sourcepub const fn redefinition(change: AnimationChange) -> Self
pub const fn redefinition(change: AnimationChange) -> Self
Creates a hint that the block definition might be redefined,
in the ways specified by change.
Sourcepub const fn replacement(change: AnimationChange) -> Self
pub const fn replacement(change: AnimationChange) -> Self
Creates a hint that the block will be replaced with another block, which differs in the
ways specified by change.