BlockAttributes

Struct BlockAttributes 

#[non_exhaustive]
pub struct BlockAttributes { pub display_name: ArcStr, pub selectable: bool, pub inventory: InvInBlock, pub ambient_sound: Ambient, pub rotation_rule: RotationPlacementRule, pub placement_action: Option<PlacementAction>, pub tick_action: Option<TickAction>, pub activation_action: Option<Operation>, pub animation_hint: AnimationHint, }
Miscellaneous properties of blocks that are not the block’s voxels.

BlockAttributes::default() will produce a reasonable set of defaults for “ordinary” blocks.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
display_name: ArcStr

The name that should be displayed to players.

The default value is the empty string. The empty string should be considered a reasonable choice for solid-color blocks with no special features.

selectable: bool

Whether players’ cursors target it or pass through it.

The default value is true.

inventory: InvInBlock

Definition of, if this block has an attached Modifier::Inventory, what size and rendering it has.

ambient_sound: Ambient

Continuous sound emission and absorption by this block.

rotation_rule: RotationPlacementRule

Rule about how this block should be rotated, or not, when placed in a Space by some agent not otherwise specifying rotation.

The default value is RotationPlacementRule::Never.

placement_action: Option<PlacementAction>

Something to do instead of placing this block in a Space.

tick_action: Option<TickAction>

Something this block does when time passes.

activation_action: Option<Operation>

Something this block does when activated with Activate.

animation_hint: AnimationHint

Advice to the renderer about how to expect this block to change, and hence what rendering strategy to use.

Note: This is automatically augmented for Primitive::Recur blocks if they contain voxels with animation hints themselves.

Implementations

Source

impl BlockAttributes

pub const fn default() -> BlockAttributes

Block attributes suitable as default values for in-game use.

This function differs from the Default::default trait implementation only in that it is a const fn.