Struct all_is_cubes::block::BlockAttributes
source · pub struct BlockAttributes {
pub display_name: ArcStr,
pub selectable: bool,
pub rotation_rule: RotationPlacementRule,
pub tick_action: Option<TickAction>,
pub activation_action: Option<Operation>,
pub animation_hint: AnimationHint,
}Expand description
Collection of miscellaneous attribute data for blocks that doesn’t come in variants.
BlockAttributes::default() will produce a reasonable set of defaults for “ordinary”
blocks.
Fields
display_name: ArcStrThe name that should be displayed to players.
The default value is the empty string. The empty string should be considered a reasonable choice for solid-color blocks with no special features.
selectable: boolWhether players’ cursors target it or pass through it.
The default value is true.
rotation_rule: RotationPlacementRuleRule about how this block should be rotated, or not, when placed in a Space by
some agent not otherwise specifying rotation.
The default value is RotationPlacementRule::Never.
tick_action: Option<TickAction>Something this block does when time passes.
activation_action: Option<Operation>Something this block does when activated with Activate.
animation_hint: AnimationHintAdvice to the renderer about how to expect this block to change, and hence what rendering strategy to use.
Note: This is automatically augmented for Primitive::Recur blocks if they
contain voxels with animation hints themselves.
Implementations
sourceimpl BlockAttributes
impl BlockAttributes
sourcepub const fn default() -> BlockAttributes
pub const fn default() -> BlockAttributes
Block attributes suitable as default values for in-game use.
This function differs from the Default::default trait implementation only
in that it is a const fn.