pub struct BlockDef { /* private fields */ }Expand description
Contains a Block and can be stored in a Universe.
Together with Primitive::Indirect, this allows mutation of a block definition such
that all its existing usages follow.
To perform such a mutation, use BlockDefTransaction.
Additionally, it caches the results of block evaluation to improve performance.
Note that this cache only updates when the owning Universe is being stepped, or when
a direct mutation to this BlockDef is performed, not when the contained Block
sends a change notification.
Implementations
Sourceimpl BlockDef
impl BlockDef
Sourcepub fn new(read_ticket: ReadTicket<'_>, block: Block) -> Self
pub fn new(read_ticket: ReadTicket<'_>, block: Block) -> Self
Constructs a new BlockDef that stores the given block (which may be replaced
in the future).
Sourcepub fn block(&self) -> &Block
pub fn block(&self) -> &Block
Returns the current block value.
Note that if you wish to get the EvaluatedBlock result, you should obtain the cached
value by calling BlockDef.evaluate(), or by using a Primitive::Indirect,
not by calling .block().evaluate(), which is not cached.
Sourcepub fn evaluate(
&self,
read_ticket: ReadTicket<'_>,
) -> Result<EvaluatedBlock, EvalBlockError>
pub fn evaluate( &self, read_ticket: ReadTicket<'_>, ) -> Result<EvaluatedBlock, EvalBlockError>
Returns the current cached evaluation of the current block value.
This returns the same success or error as Block::from(handle_to_self).evaluate() would,
not the same as .block().evaluate() would.