Struct all_is_cubes::block::BlockDef

source ·
pub struct BlockDef { /* private fields */ }
Contains a Block and can be stored in a Universe. Together with Primitive::Indirect, this allows mutation of a block definition such that all its existing usages follow.

To perform such a mutation, use BlockDefTransaction.

Additionally, it caches the results of block evaluation to improve performance. Note that this cache only updates when the owning Universe is being stepped, or when a direct mutation to this BlockDef is performed, not when the contained Block sends a change notification.

Implementations

source

impl BlockDef

source

pub fn new(block: Block) -> Self

Constructs a new BlockDef that stores the given block (which may be replaced in the future).

source

pub fn block(&self) -> &Block

Returns the current block value.

Note that if you wish to get the EvaluatedBlock result, you should obtain the cached value by calling BlockDef.evaluate(), or by using a Primitive::Indirect, not by calling .block().evaluate(), which is not cached.

source

pub fn evaluate(&self) -> Result<EvaluatedBlock, EvalBlockError>

Returns the current cached evaluation of the current block value.

This returns the same success or error as Block::from(handle_to_self).evaluate() would, not the same as .block().evaluate() would.