Struct all_is_cubes::block::Move
source · #[non_exhaustive]pub struct Move {
pub direction: Face6,
pub distance: u16,
pub velocity: i16,
}Expand description
Data for Modifier::Move; displaces the block out of the grid, cropping it.
A pair of Moves can depict a block moving between two cubes.
Animation
- If the
distanceis zero then the modifier will remove itself, if possible, on the next tick. - If the
distanceandvelocityare such that the block is out of view and will never strt being in view, the block will be replaced withAIR.
(TODO: Define the conditions for “if possible”.)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.direction: Face6The direction in which the block is displaced.
distance: u16The distance, in 1/256ths, by which it is displaced.
velocity: i16The velocity per tick with which the displacement is changing.
TODO: “Per tick” is a bad unit.
Implementations
sourceimpl Move
impl Move
sourcepub fn new(direction: Face6, distance: u16, velocity: i16) -> Self
pub fn new(direction: Face6, distance: u16, velocity: i16) -> Self
TODO: make a cleaner, less internals-ish constructor
sourcepub fn paired_move(
direction: Face6,
distance: u16,
velocity: i16,
) -> [Modifier; 2]
pub fn paired_move( direction: Face6, distance: u16, velocity: i16, ) -> [Modifier; 2]
Create a pair of Modifier::Moves to displace a block.
The first goes on the block being moved and the second on the air
it’s moving into.
TODO: This is going to need to change again in order to support moving one block in and another out at the same time.