#[non_exhaustive]pub struct Input {
pub velocity_input: FreeVector,
pub jump: bool,
pub set_selected_slots: [Option<Ix>; 3],
}Expand description
Commands produced by the player’s input and executed by the character.
This data is not persisted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.velocity_input: FreeVectorVelocity specified by user input, which the actual velocity is smoothly adjusted towards.
Maximum range for normal keyboard input should be -1 to 1
jump: boolSet this to true to jump during the next step.
set_selected_slots: [Option<Ix>; 3]Indices into the Inventory slots of this character, which identify the tools currently
in use / “in hand”.
Set elements to Some to change which slots are selected.
None means no change from the current value.