pub struct Spawn { /* private fields */ }Expand description
Defines the initial state of a Character that is being created or moved into a Space.
TODO: This is lacking a full set of accessor methods to be viewable+editable.
Serialization stability warning
This type implements serde::Serialize and serde::Deserialize, but serialization
support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes
will be able to deserialize data which is serialized by this version.
Additionally, the serialization schema is designed with serde_json in mind. It is not
guaranteed that using a different data format crate, which may use a different subset of
the information exposed via serde::Serialize, will produce stable results.
Implementations
Sourceimpl Spawn
impl Spawn
Sourcepub fn default_for_new_space(bounds: GridAab) -> Self
pub fn default_for_new_space(bounds: GridAab) -> Self
Create the default Spawn configuration for a Space.
TODO: There is no good default, really: we don’t know if it is better to be outside the space looking in or to be within it at some particular position. Come up with some kind of hint that we can use to configure this better without necessarily mandating a specification.
Sourcepub fn set_eye_position(&mut self, position: impl Into<FreePoint>)
pub fn set_eye_position(&mut self, position: impl Into<FreePoint>)
Sets the position at which the character will appear, in terms of its viewpoint.
Sourcepub fn set_bounds(&mut self, bounds: GridAab)
pub fn set_bounds(&mut self, bounds: GridAab)
Sets the bounds within which the character may be placed is allowed.
Sourcepub fn set_look_direction(&mut self, direction: impl Into<FreeVector>)
pub fn set_look_direction(&mut self, direction: impl Into<FreeVector>)
Sets the direction the character should be facing, or looking at.
The results are unspecified but harmless if the direction is zero or NaN.
Sourcepub fn set_inventory(&mut self, inventory: Vec<Slot>)
pub fn set_inventory(&mut self, inventory: Vec<Slot>)
Sets the starting inventory items.