pub struct IconRow { /* private fields */ }Expand description
Positioning of a displayed row of inventory icons; part of InvInBlock.
Implementations
Sourceimpl IconRow
impl IconRow
Sourcepub fn new(slot_range: Range<Ix>, origin: GridPoint, stride: GridVector) -> Self
pub fn new(slot_range: Range<Ix>, origin: GridPoint, stride: GridVector) -> Self
Constructs an IconRow.
slot_rangeis the the portion of the inventory that is displayed.originis the lower corner of the location within the voxels where the first slot inslot_rangeis to be displayed.strideis the translation between adjacent slots.
Panics
Panics if slot_range has end less than start.