#[non_exhaustive]pub enum InGenError {
Other(Box<dyn Error + Send + Sync>),
Gen(Box<GenError>),
Insert(InsertError),
Provider(ProviderError),
Space(Error),
SetCube(SetCubeError),
UniverseTransaction(ExecuteError<UniverseTransaction>),
SpaceTransaction(ExecuteError<SpaceTransaction>),
}Expand description
Aggregation of types of errors that might occur in “world generation”.
This is distinct from GenError in that this type is returned from functions
responsible for generation, and that type is returned from functions that
manage generation — that invoke the first kind and (usually) store its result
in the Universe. This separation is intended to encourage more precise
attribution of the source of the error despite implicit conversions, because a
“nested” GenError will be obligated to be wrapped in InGenError rather than
mistakenly taken as the same level.
TODO: Work this into a coherent set of error cases rather than purely “I saw one of these once, so add it”.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Other(Box<dyn Error + Send + Sync>)
Generic error container for unusual situations.
Gen(Box<GenError>)
Something else needed to be generated and that failed.
Insert(InsertError)
Failed to insert the generated items in the Universe.
Provider(ProviderError)
Failed to find a needed dependency.
Space(Error)
Failed during Space construction.
SetCube(SetCubeError)
Failed during Space manipulation.
UniverseTransaction(ExecuteError<UniverseTransaction>)
Failed during a transaction executed as part of generation.
SpaceTransaction(ExecuteError<SpaceTransaction>)
Failed during a transaction executed as part of generation.
Implementations