#[repr(u8)]pub enum Octant {
Nnn = 0,
Nnp = 1,
Npn = 2,
Npp = 3,
Pnn = 4,
Pnp = 5,
Ppn = 6,
Ppp = 7,
}Expand description
Identifies one of eight octants, or elements of a 2×2×2 cube.
Used with OctantMask and OctantMap.
This enum’s discriminants are not currently to be considered stable; they may be reordered.
Variants
Nnn = 0
The -X, -Y, -Z octant.
Nnp = 1
The -X, -Y, +Z octant.
Npn = 2
The -X, +Y, -Z octant.
Npp = 3
The -X, +Y, +Z octant.
Pnn = 4
The +X, -Y, -Z octant.
Pnp = 5
The +X, -Y, +Z octant.
Ppn = 6
The +X, +Y, -Z octant.
Ppp = 7
The +X, +Y, +Z octant.
Implementations
Sourceimpl Octant
impl Octant
Sourcepub fn try_from_positive_cube(cube: Cube) -> Option<Octant>
pub fn try_from_positive_cube(cube: Cube) -> Option<Octant>
Given a cube in the volume (0..2)³, return which octant of that volume it is.
Sourcepub fn try_from_01<T, U>(
corner_or_translation: Vector3D<T, U>,
) -> Option<Octant>
pub fn try_from_01<T, U>( corner_or_translation: Vector3D<T, U>, ) -> Option<Octant>
Given the low corner of an octant in the volume (0..2)³, return which octant it is.
That is, each coordinate of the returned Vector3D is either 0 or 1.
This is equivalent to Self::try_from_positive_cube() but with more flexible input.
TODO: better trait bounds would be Zero + One
Sourcepub fn from_vector(vector: Vector3D<f64, Cube>) -> Octant
pub fn from_vector(vector: Vector3D<f64, Cube>) -> Octant
Returns the octant the given vector points toward, when interpreted as pointing away from the center point where all octants meet.
Ties due to zero components are broken in the positive direction.
Sourcepub fn to_positive_cube(self) -> Cube
pub fn to_positive_cube(self) -> Cube
Returns this octant of the volume (0..2)³.
That is, each coordinate of the returned Cube is either 0 or 1.