Struct all_is_cubes::math::FaceMap
source · pub struct FaceMap<V> {
pub nx: V,
pub ny: V,
pub nz: V,
pub px: V,
pub py: V,
pub pz: V,
}Expand description
Container for values keyed by Face6s. Always holds exactly six elements.
Fields
nx: VThe value whose key is Face6::NX.
ny: VThe value whose key is Face6::NY.
nz: VThe value whose key is Face6::NZ.
px: VThe value whose key is Face6::PX.
py: VThe value whose key is Face6::PY.
pz: VThe value whose key is Face6::PZ.
Implementations
sourceimpl<V> FaceMap<V>
impl<V> FaceMap<V>
sourcepub fn negatives<U>(self) -> Vector3D<V, U>where
V: Copy,
pub fn negatives<U>(self) -> Vector3D<V, U>where
V: Copy,
Returns a vector containing the values for each negative face.
sourcepub fn positives<U>(self) -> Vector3D<V, U>where
V: Copy,
pub fn positives<U>(self) -> Vector3D<V, U>where
V: Copy,
Returns a vector containing the values for each positive face.
sourcepub fn iter(&self) -> impl Iterator<Item = (Face6, &V)>
pub fn iter(&self) -> impl Iterator<Item = (Face6, &V)>
Iterate over the map’s key-value pairs by reference, in the same order as Face6::ALL.
sourcepub fn iter_mut(&mut self) -> impl Iterator<Item = (Face6, &mut V)>
pub fn iter_mut(&mut self) -> impl Iterator<Item = (Face6, &mut V)>
Iterate over the map’s key-value pairs by mutable reference, in the same order as Face6::ALL.
sourcepub fn values(&self) -> impl Iterator<Item = &V>
pub fn values(&self) -> impl Iterator<Item = &V>
Iterate over the map values by reference, in the same order as Face6::ALL.
sourcepub fn into_values(self) -> [V; 6]
pub fn into_values(self) -> [V; 6]
Convert to an array, whose elements are arranged in the same order as Face6::ALL.
sourcepub fn into_values_iter(self) -> impl Iterator<Item = V>
pub fn into_values_iter(self) -> impl Iterator<Item = V>
Convert to an iterator, whose items are arranged in the same order as Face6::ALL.
sourcepub fn zip<U, R>(
self,
other: FaceMap<U>,
f: impl FnMut(Face6, V, U) -> R,
) -> FaceMap<R>
pub fn zip<U, R>( self, other: FaceMap<U>, f: impl FnMut(Face6, V, U) -> R, ) -> FaceMap<R>
Combine two FaceMaps using a function applied to each pair of corresponding values.
sourcepub fn with(self, face: Face6, value: V) -> FaceMap<V>
pub fn with(self, face: Face6, value: V) -> FaceMap<V>
Returns this map with one entry’s value replaced.
This may be used for constructing a map with only one interesting entry:
use all_is_cubes::math::{Face6, FaceMap};
assert_eq!(
FaceMap::default().with(Face6::PY, 10),
{
let mut m = FaceMap::default();
m[Face6::PY] = 10;
m
},
);sourcepub fn rotate(self, rotation: GridRotation) -> FaceMap<V>
pub fn rotate(self, rotation: GridRotation) -> FaceMap<V>
Shuffle the values in this map according to the given rotation.
sourceimpl<V> FaceMap<V>where
V: Copy,
impl<V> FaceMap<V>where
V: Copy,
sourcepub const fn repeat_copy(value: V) -> FaceMap<V>
pub const fn repeat_copy(value: V) -> FaceMap<V>
Constructs a FaceMap containing copies of the provided value.
This is practically identical to FaceMap::repeat() except that it is a
const fn. It may be removed from future major versions once Rust supports const
trait function calls.