pub struct OctantMap<T>(/* private fields */);Expand description
Collection of 8 values keyed by Octants.
If the values are bool, use OctantMask instead for a more efficient representation.
Implementations
Sourceimpl<T> OctantMap<T>
impl<T> OctantMap<T>
Sourcepub fn from_fn(function: impl FnMut(Octant) -> T) -> OctantMap<T>
pub fn from_fn(function: impl FnMut(Octant) -> T) -> OctantMap<T>
Constructs an OctantMap by using the provided function to compute
a value for each octant.
Sourcepub fn repeat(value: T) -> OctantMap<T>where
T: Clone,
pub fn repeat(value: T) -> OctantMap<T>where
T: Clone,
Constructs an OctantMap by cloning the provided value.
Sourcepub fn to_mask(&self, predicate: impl FnMut(&T) -> bool) -> OctantMask
pub fn to_mask(&self, predicate: impl FnMut(&T) -> bool) -> OctantMask
Returns an OctantMask constructed by applying the given predicate to each octant
of the data in self.
Sourcepub fn iter(&self) -> impl Iterator<Item = (Octant, &T)>
pub fn iter(&self) -> impl Iterator<Item = (Octant, &T)>
Returns an iterator over all elements by reference, and their octants.
The order of iteration is not currently guarateed.