pub struct ZeroOne<T>(/* private fields */);Expand description
A floating-point number which is within the range +0 to +1 (inclusive).
This may be used for alpha blending, reflectance, lerps, and anything else where values outside the range 0 to 1 is meaningless. It is closed under multiplication.
Because NaN and negative zero are excluded, this type implements Eq straightforwardly,
and can reliably be used as a map key for caching, interning, etc.
Implementations
Sourceimpl<T> ZeroOne<T>where
T: FloatCore,
impl<T> ZeroOne<T>where
T: FloatCore,
Sourcepub const unsafe fn new_unchecked(value: T) -> ZeroOne<T>
pub const unsafe fn new_unchecked(value: T) -> ZeroOne<T>
Sourcepub const fn into_inner(self) -> T
pub const fn into_inner(self) -> T
Unwraps the value without modifying it.
Sourcepub fn complement(self) -> ZeroOne<T>
pub fn complement(self) -> ZeroOne<T>
Returns 1.0 - self.
The result cannot be out of range, so this operation is always successful.
Sourceimpl ZeroOne<f32>
impl ZeroOne<f32>
Sourcepub const fn new_strict(value: f32) -> ZeroOne<f32>
pub const fn new_strict(value: f32) -> ZeroOne<f32>
Wraps the given value in ZeroOne.
- If
valueis in range, returns wrappedvalue. - If
valueis zero of either sign, returns wrapped positive zero. This is lossy, but corresponds to the IEEE 754 idea that -0.0 == +0.0. - If
valueis out of range or NaN, panics.
Sourcepub const fn new_clamped(value: f32) -> ZeroOne<f32>
pub const fn new_clamped(value: f32) -> ZeroOne<f32>
Wraps the given value in ZeroOne.
- If the value is NaN, panics.
- If the value is out of range, replaces it with the nearest in-range value (0 or 1).
Sourceimpl ZeroOne<f64>
impl ZeroOne<f64>
Sourcepub const fn new_strict(value: f64) -> ZeroOne<f64>
pub const fn new_strict(value: f64) -> ZeroOne<f64>
Wraps the given value in ZeroOne.
- If
valueis in range, returns wrappedvalue. - If
valueis zero of either sign, returns wrapped positive zero. This is lossy, but corresponds to the IEEE 754 idea that -0.0 == +0.0. - If
valueis out of range or NaN, panics.
Sourcepub const fn new_clamped(value: f64) -> ZeroOne<f64>
pub const fn new_clamped(value: f64) -> ZeroOne<f64>
Wraps the given value in ZeroOne.
- If the value is NaN, panics.
- If the value is out of range, replaces it with the nearest in-range value (0 or 1).