Struct all_is_cubes::physics::MoveSegment
source · #[non_exhaustive]pub struct MoveSegment {
pub delta_position: FreeVector,
pub stopped_by: Option<Contact>,
}Expand description
One of the individual straight-line movement segments of a BodyStepInfo.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delta_position: FreeVectorThe change in position.
stopped_by: Option<Contact>What solid object stopped this segment from continuing further (there may be others, but this is one of them), or None if there was no obstacle.