pub struct Read<'ticket> { /* private fields */ }Expand description
Read access to a Space that may be currently in a Universe.
Obtain this using Handle::read() or Space::read().
Implementations
Sourceimpl Read<'_>
impl Read<'_>
Sourcepub fn bounds(&self) -> GridAab
pub fn bounds(&self) -> GridAab
Returns the GridAab describing the bounds of this space; no blocks may exist
outside it.
Sourcepub fn get_block_index(&self, position: impl Into<Cube>) -> Option<BlockIndex>
pub fn get_block_index(&self, position: impl Into<Cube>) -> Option<BlockIndex>
Returns the internal unstable numeric ID for the block at the given position,
which may be mapped to a Block by Read::block_data().
If you are looking for simple access, use space[position] (the
core::ops::Index trait) instead.
These IDs may be used to perform efficient processing of many blocks, but they may be renumbered after any mutation.
Sourcepub fn get_evaluated(&self, position: impl Into<Cube>) -> &EvaluatedBlock
pub fn get_evaluated(&self, position: impl Into<Cube>) -> &EvaluatedBlock
Returns the EvaluatedBlock of the block in this space at the given position.
If out of bounds, returns the evaluation of AIR.
Sourcepub fn get_lighting(&self, cube: impl Into<Cube>) -> PackedLight
pub fn get_lighting(&self, cube: impl Into<Cube>) -> PackedLight
Returns the light occupying the given cube.
This value may be considered as representing the average of the light reflecting off of all surfaces within, or immediately adjacent to and facing toward, this cube. If there are no such surfaces, or if the given position is out of bounds, the result is arbitrary. If the position is within an opaque block, the result is black.
Lighting is updated asynchronously after modifications, so all above claims about the meaning of this value are actually “will eventually be, if no more changes are made”.
Sourcepub fn extract<'s, C, V>(
&'s self,
bounds: GridAab,
extractor: impl FnMut(Extract<'s>) -> V,
) -> Vol<C>
pub fn extract<'s, C, V>( &'s self, bounds: GridAab, extractor: impl FnMut(Extract<'s>) -> V, ) -> Vol<C>
Copy data out of a portion of the space in a caller-chosen format.
The given bounds must be fully contained within self.bounds().
Sourcepub fn block_data(&self) -> &[SpaceBlockData]
pub fn block_data(&self) -> &[SpaceBlockData]
Returns data about all the blocks assigned internal IDs (indices) in the space, as well as placeholder data for any deallocated indices.
The indices of this slice correspond to the results of Space::get_block_index().
Sourcepub fn fluff(
&self,
) -> impl Listen<Msg = SpaceFluff, Listener = DynListener<SpaceFluff>> + '_
pub fn fluff( &self, ) -> impl Listen<Msg = SpaceFluff, Listener = DynListener<SpaceFluff>> + '_
Returns the source of fluff occurring in this space.
Sourcepub fn physics(&self) -> &SpacePhysics
pub fn physics(&self) -> &SpacePhysics
Returns the current SpacePhysics data, which determines global characteristics
such as the behavior of light and gravity.
Sourcepub fn behaviors(&self) -> &BehaviorSet<Space>
pub fn behaviors(&self) -> &BehaviorSet<Space>
Returns the BehaviorSet of behaviors attached to this space.