pub struct SpaceBehaviorAttachment { /* private fields */ }Expand description
Description of where in a Space a Behavior<Space>
exists.
Implementations
Sourceimpl SpaceBehaviorAttachment
impl SpaceBehaviorAttachment
Sourcepub fn new(bounds: GridAab) -> Self
pub fn new(bounds: GridAab) -> Self
Constructs a new SpaceBehaviorAttachment with no rotation.
Sourcepub fn bounds(&self) -> GridAab
pub fn bounds(&self) -> GridAab
Returns the bounds of this attachment, which specify (without mandating) what region the behavior should affect.
Sourcepub fn rotation(&self) -> GridRotation
pub fn rotation(&self) -> GridRotation
Returns the rotation of this attachment, which specifies, if applicable, which orientation the behavior should operate in relative to the space. The exact meaning of this is up to the behavior.
TODO: explain with an example once we have a good one