pub struct SpaceTransaction { /* private fields */ }Expand description
A Transaction that modifies a Space.
Implementations
Sourceimpl SpaceTransaction
impl SpaceTransaction
Sourcepub fn at(&mut self, cube: Cube) -> &mut CubeTransaction
pub fn at(&mut self, cube: Cube) -> &mut CubeTransaction
Allows modifying the part of this transaction which is a CubeTransaction at the given
cube, creating it if necessary (as CubeTransaction::default()).
You can replace the transaction or use CubeTransaction::merge_from() to merge in
another transaction.
This is for incremental construction of a complex transaction;
to create a transaction affecting a single cube, CubeTransaction::at() will be more
convenient.
Sourcepub fn filling<F>(region: GridAab, function: F) -> Self
pub fn filling<F>(region: GridAab, function: F) -> Self
Construct a SpaceTransaction which modifies a volume by applying a CubeTransaction
computed by function to each cube.
Sourcepub fn set_cube(
cube: impl Into<Cube>,
old: Option<Block>,
new: Option<Block>,
) -> Self
pub fn set_cube( cube: impl Into<Cube>, old: Option<Block>, new: Option<Block>, ) -> Self
Construct a SpaceTransaction for a single cube.
If old is not None, requires that the existing block is that block or the
transaction will fail.
If new is not None, replaces the existing block with new.
TODO: Consider replacing all uses of this with CubeTransaction::replacing().
Sourcepub fn draw_target<C>(
&mut self,
transform: Gridgid,
) -> DrawingPlane<'_, Self, C>
pub fn draw_target<C>( &mut self, transform: Gridgid, ) -> DrawingPlane<'_, Self, C>
Provides an DrawTarget
adapter for 2.5D drawing.
For more information on how to use this, see
all_is_cubes::drawing.
Sourcepub fn nonconserved(self) -> Self
pub fn nonconserved(self) -> Self
Marks all cube modifications in this transaction as non-conservative.
This means that two transactions which both place the same block in a given cube may be merged, whereas the default state is that they will conflict (on the principle that such a merge could cause there to be fewer total occurrences of that block than intended).
Also, the transaction will not fail if some of its cubes are outside the bounds of
the Space.
Sourcepub fn behaviors(t: BehaviorSetTransaction<Space>) -> Self
pub fn behaviors(t: BehaviorSetTransaction<Space>) -> Self
Modify the space’s BehaviorSet.
Sourcepub fn add_behavior<B>(bounds: GridAab, behavior: B) -> Self
pub fn add_behavior<B>(bounds: GridAab, behavior: B) -> Self
Add a behavior to the Space.
This is a shortcut for creating a BehaviorSetTransaction.
Sourcepub fn bounds_only_cubes(&self) -> Option<GridAab>
pub fn bounds_only_cubes(&self) -> Option<GridAab>
Computes the region of cubes directly affected by this transaction. Ignores behaviors.
Returns None if no cubes are affected.
TODO: Handle the case where the total volume is too large.
(Maybe GridAab should lose that restriction.)
Sourcepub fn bounds(&self) -> Option<GridAab>
pub fn bounds(&self) -> Option<GridAab>
Computes the region affected by this transaction.
Returns None if no specific regions of the space are affected.
Sourcepub fn execute_m(
self,
target: &mut Mutation<'_, '_>,
) -> Result<(), ExecuteError<Self>>
pub fn execute_m( self, target: &mut Mutation<'_, '_>, ) -> Result<(), ExecuteError<Self>>
As Transaction::execute(), but taking a Mutation instead of a Space.