pub struct Clock { /* private fields */ }Expand description
Defines the passage of time in a Universe.
See TickSchedule for details on what is possible and why.
TODO: Should paused be part of the clock’s state?
Implementations
Sourceimpl Clock
impl Clock
Sourcepub const fn new(schedule: TickSchedule, phase: u16) -> Self
pub const fn new(schedule: TickSchedule, phase: u16) -> Self
Creates a new Clock with the given state.
If the phase is out of range, it is reduced modulo schedule.divisor.
Sourcepub fn schedule(&self) -> TickSchedule
pub fn schedule(&self) -> TickSchedule
Returns the schedule which this clock obeys.
Sourcepub fn advance(&mut self, paused: bool) -> Tick
pub fn advance(&mut self, paused: bool) -> Tick
If paused is false, advances this clock to the next instant (as defined by
the schedule) and returns the Tick defining the transition between those
instants.
If paused is true, returns a paused Tick for the current instant.
See Tick::paused for information on the meaning of pausing.
Sourcepub fn next_tick(&self, paused: bool) -> Tick
pub fn next_tick(&self, paused: bool) -> Tick
Returns the tick that will happen the next time Self::advance() is called,
if the schedule is not changed before then.