Struct all_is_cubes::transaction::CommitError

source ·
pub struct CommitError(/* private fields */);
Type of “unexpected errors” from Transaction::commit().

Implementations

source

impl CommitError

source

pub fn catch<T, E: ErrorIfStd + Send + Sync + 'static>(error: E) -> Self

Wrap an arbitrary unexpected error as a CommitError. T should be the type of the transaction that caught it.

source

pub fn message<T>(message: String) -> Self

Construct a CommitError with a string description. T should be the type of the transaction that detected the problem.

source

pub fn context(self, component: String) -> Self

Report an error propagating up from an inner transaction. component should describe which part of the current transaction returned the error from its commit().