Struct all_is_cubes::transaction::CommitError
source · pub struct CommitError(/* private fields */);Expand description
Type of “unexpected errors” from Transaction::commit().
Implementations
sourceimpl CommitError
impl CommitError
sourcepub fn catch<T, E: ErrorIfStd + Send + Sync + 'static>(error: E) -> Self
pub fn catch<T, E: ErrorIfStd + Send + Sync + 'static>(error: E) -> Self
Wrap an arbitrary unexpected error as a CommitError.
T should be the type of the transaction that caught it.
sourcepub fn message<T>(message: String) -> Self
pub fn message<T>(message: String) -> Self
Construct a CommitError with a string description.
T should be the type of the transaction that detected the problem.